//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Core/Contrib/RoughMultiLayerContribution.h
//! @brief     Defines class RoughMultiLayerContribution.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_CORE_CONTRIB_ROUGHMULTILAYERCONTRIBUTION_H
#define BORNAGAIN_CORE_CONTRIB_ROUGHMULTILAYERCONTRIBUTION_H

#include "Base/Types/Complex.h"

class ProcessedSample;
class DiffuseElement;

//! Computes the diffuse reflection from the rough interfaces of a multilayer.
//! Used by DWBAComputation.

class RoughMultiLayerContribution final {
public:
    RoughMultiLayerContribution(const ProcessedSample& re_sample);

    void compute(DiffuseElement& ele) const;

private:
    const ProcessedSample& m_re_sample;

    complex_t get_refractive_term(size_t ilayer, double wavelength) const;
    complex_t get_sum8terms(size_t ilayer, const DiffuseElement& ele) const;
};

#endif // BORNAGAIN_CORE_CONTRIB_ROUGHMULTILAYERCONTRIBUTION_H
#endif // USER_API
