//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Items/BackgroundItems.cpp
//! @brief     Implements BackgroundItem classes
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Items/BackgroundItems.h"
#include "Core/Background/ConstantBackground.h"
#include "Core/Background/PoissonNoiseBackground.h"

BackgroundItem::BackgroundItem(const QString& model_type) : SessionItem(model_type) {}

// Background none
/* ------------------------------------------------ */

NoBackgroundItem::NoBackgroundItem() : BackgroundItem(M_TYPE) {}

std::unique_ptr<IBackground> NoBackgroundItem::createBackground() const
{
    return {};
}

// Constant background
/* ------------------------------------------------ */

namespace {
const QString constant_background_value_tooltip = "Constant background value [counts/pixel]";
}

ConstantBackgroundItem::ConstantBackgroundItem() : BackgroundItem(M_TYPE)
{
    addProperty(P_VALUE, 0.0)
        ->setLimits(RealLimits::nonnegative())
        .setToolTip(constant_background_value_tooltip);
}

std::unique_ptr<IBackground> ConstantBackgroundItem::createBackground() const
{
    return std::make_unique<ConstantBackground>(getItemValue(P_VALUE).toDouble());
}

double ConstantBackgroundItem::backgroundValue() const
{
    return getItemValue(P_VALUE).toDouble();
}

void ConstantBackgroundItem::setBackgroundValue(double value)
{
    setItemValue(P_VALUE, value);
}

// Background consisting of Poisson noise
/* ------------------------------------------------ */

PoissonNoiseBackgroundItem::PoissonNoiseBackgroundItem() : BackgroundItem(M_TYPE) {}

std::unique_ptr<IBackground> PoissonNoiseBackgroundItem::createBackground() const
{
    return std::make_unique<PoissonNoiseBackground>();
}
