//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Items/BeamWavelengthItem.h
//! @brief     Defines class BeamWavelengthItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_ITEMS_BEAMWAVELENGTHITEM_H
#define BORNAGAIN_GUI_ITEMS_BEAMWAVELENGTHITEM_H

#include "GUI/Items/BeamDistributionItem.h"

class BA_CORE_API_ BeamWavelengthItem : public BeamDistributionItem {
public:
    static constexpr auto M_TYPE{"BeamWavelength"};

    BeamWavelengthItem();
    double wavelength() const;

protected:
    BeamWavelengthItem(const QString& model_type, Distributions distribution_group);

private:
    static const bool m_show_mean = true;
};

class SpecularBeamWavelengthItem : public BeamWavelengthItem {
public:
    static constexpr auto M_TYPE{"SpecularBeamWavelength"};

    SpecularBeamWavelengthItem();
    void setToRange(const RealLimits& limits);
};

#endif // BORNAGAIN_GUI_ITEMS_BEAMWAVELENGTHITEM_H
