//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Items/FootprintItems.h
//! @brief     Declares FootprintItem classes
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_ITEMS_FOOTPRINTITEMS_H
#define BORNAGAIN_GUI_ITEMS_FOOTPRINTITEMS_H

#include "GUI/Items/SessionItem.h"

class IFootprintFactor;

class BA_CORE_API_ FootprintItem : public SessionItem {
public:
    virtual ~FootprintItem();
    virtual std::unique_ptr<IFootprintFactor> createFootprint() const = 0;

protected:
    explicit FootprintItem(const QString& model_type);
};

class FootprintNoneItem : public FootprintItem {
public:
    static constexpr auto M_TYPE{"NoFootprint"};

    FootprintNoneItem();
    virtual ~FootprintNoneItem();
    std::unique_ptr<IFootprintFactor> createFootprint() const override;
};

class FootprintGaussianItem : public FootprintItem {
private:
    static constexpr auto P_VALUE{"Width ratio"};

public:
    static constexpr auto M_TYPE{"GaussianFootrpint"};

    FootprintGaussianItem();
    virtual ~FootprintGaussianItem();
    std::unique_ptr<IFootprintFactor> createFootprint() const override;
    double gaussianFootprintValue() const;
    void setGaussianFootprintValue(double value);
};

class FootprintSquareItem : public FootprintItem {
private:
    static constexpr auto P_VALUE{"Width ratio"};

public:
    static constexpr auto M_TYPE{"SquareFootprint"};

    FootprintSquareItem();
    virtual ~FootprintSquareItem();
    std::unique_ptr<IFootprintFactor> createFootprint() const override;
    double squareFootprintValue() const;
    void setSquareFootprintValue(double value);
};

#endif // BORNAGAIN_GUI_ITEMS_FOOTPRINTITEMS_H
