//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Items/ItemWithMaterial.cpp
//! @brief     Implements class ItemWithMaterial
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Items/ItemWithMaterial.h"
#include "GUI/Items/JobItem.h"
#include "GUI/Items/JobModelFunctions.h"
#include "GUI/Items/MaterialItemContainer.h"
#include "GUI/Items/MaterialItemUtils.h"

void ItemWithMaterial::setMaterial(const MaterialItem* materialItem)
{
    setItemValue(P_MATERIAL, materialItem->identifier());
}

void ItemWithMaterial::setMaterial(const QString& materialIdentifier)
{
    setItemValue(P_MATERIAL, materialIdentifier);
}

bool ItemWithMaterial::isMaterialPropertyName(const QString& name)
{
    return name == P_MATERIAL;
}

void ItemWithMaterial::setMaterialUndefined()
{
    setItemValue(P_MATERIAL, QString());
}

QColor ItemWithMaterial::materialColor() const
{
    const auto parentJob = GUI::Model::JobFunctions::findJobItem(this);
    if (parentJob)
        return parentJob->materialContainerItem()->findMaterialById(materialIdentifier())->color();

    return GUI::Model::MaterialItemUtils::findMaterial(materialIdentifier())->color();
}

QString ItemWithMaterial::materialName() const
{
    const auto parentJob = GUI::Model::JobFunctions::findJobItem(this);
    if (parentJob)
        return parentJob->materialContainerItem()
            ->findMaterialById(materialIdentifier())
            ->itemName();

    return GUI::Model::MaterialItemUtils::findMaterial(materialIdentifier())->itemName();
}

QString ItemWithMaterial::materialIdentifier() const
{
    return getItemValue(P_MATERIAL).toString();
}

ItemWithMaterial::ItemWithMaterial(const QString& model_type) : SessionGraphicsItem(model_type)
{
    addProperty(P_MATERIAL, GUI::Model::MaterialItemUtils::defaultMaterialIdentifier())
        ->setToolTip("Material this item is made of")
        .setEditorType(SessionItem::EDITOR_TYPE_MATERIAL);
}
