//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Items/MaterialItemContainer.cpp
//! @brief     Implements class MaterialItemContainer
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Items/MaterialItemContainer.h"
#include "GUI/Items/MaterialItem.h"
#include "GUI/Items/SessionModel.h"
#include "GUI/utils/Helpers.h"

MaterialItemContainer::MaterialItemContainer() : SessionItem(M_TYPE)
{
    setItemName("Materials");
    registerTag(T_MATERIALS, 0, -1, {MaterialItem::M_TYPE});
}

MaterialItem* MaterialItemContainer::insertCopy(MaterialItem* material_item)
{
    MaterialItem* item_copy = model()->copyItem(material_item, this, T_MATERIALS);
    item_copy->setIdentifier(GUI::Helpers::createUuid());

    return item_copy;
}

MaterialItem* MaterialItemContainer::findMaterialById(QString id)
{
    return const_cast<MaterialItem*>(
        static_cast<const MaterialItemContainer*>(this)->findMaterialById(id));
}

const MaterialItem* MaterialItemContainer::findMaterialById(QString id) const
{
    auto materials = getItems(T_MATERIALS);
    for (auto item : materials) {
        auto material = dynamic_cast<MaterialItem*>(item);
        if (material->identifier() == id)
            return material;
    }
    return nullptr;
}

QVector<MaterialItem*> MaterialItemContainer::getMaterials()
{
    return items<MaterialItem>(T_MATERIALS);
}
