//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Items/MaterialItemUtils.h
//! @brief     Defines namespace GUI::Model::MaterialItemUtils
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_ITEMS_MATERIALITEMUTILS_H
#define BORNAGAIN_GUI_ITEMS_MATERIALITEMUTILS_H

#include "GUI/Items/MaterialItem.h"
#include <QColor>
#include <QString>
#include <memory>

class Material;
class MaterialItemContainer;
class ItemWithMaterial;
class ParticleLayoutItem;

namespace GUI::Model::MaterialItemUtils {

QColor suggestMaterialColor(const QString& name);
QColor randomMaterialColor();

QString defaultMaterialIdentifier();

std::unique_ptr<Material> createDomainMaterial(const QString& materialIdentifier);
std::unique_ptr<Material> createDomainMaterial(const QString& materialIdentifier,
                                               const MaterialItemContainer& container);

MaterialItem* findMaterial(const QString& materialIdentifier);

//! Gather material property items from a given item
QVector<ItemWithMaterial*> itemsWithMaterial(ParticleLayoutItem* item);

} // namespace GUI::Model::MaterialItemUtils

#endif // BORNAGAIN_GUI_ITEMS_MATERIALITEMUTILS_H
