//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Items/ParticleCoreShellItem.h
//! @brief     Defines class ParticleCoreShellItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_ITEMS_PARTICLECORESHELLITEM_H
#define BORNAGAIN_GUI_ITEMS_PARTICLECORESHELLITEM_H

#include "GUI/Items/ItemWithParticles.h"

class ParticleCoreShell;
class ParticleItem;
class VectorItem;

class BA_CORE_API_ ParticleCoreShellItem : public ItemWithParticles {
private:
    static constexpr auto T_CORE{"Core tag"};
    static constexpr auto T_SHELL{"Shell tag"};

public:
    static constexpr auto M_TYPE{"ParticleCoreShell"};

    ParticleCoreShellItem();

    std::unique_ptr<ParticleCoreShell> createParticleCoreShell() const;

    ParticleItem* core() const;
    void setCore(ParticleItem* core);
    ParticleItem* createCore();
    static bool isCoreTagName(const QString& name);

    ParticleItem* shell() const;
    void setShell(ParticleItem* core);
    ParticleItem* createShell();
    static bool isShellTagName(const QString& name);
};

#endif // BORNAGAIN_GUI_ITEMS_PARTICLECORESHELLITEM_H
