//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Mapper/ModelUtils.cpp
//! @brief     Implements ModelUtils namespace
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Mapper/ModelUtils.h"
#include "GUI/Items/SessionModel.h"
#include <QAbstractItemModel>
#include <QModelIndex>

QStringList GUI::Model::ItemUtils::topItemNames(const SessionModel* model, const QString& modelType)
{
    QStringList result;

    for (auto item : model->topItems())
        if (modelType.isEmpty() || modelType == item->modelType())
            result.append(item->itemName());

    return result;
}

void GUI::Model::ItemUtils::iterate(const QModelIndex& index, const QAbstractItemModel* model,
                                    const std::function<void(const QModelIndex&)>& fun)
{
    if (index.isValid())
        fun(index);

    if (!model->hasChildren(index))
        return;

    for (int i = 0; i < model->rowCount(index); ++i)
        for (int j = 0; j < model->columnCount(index); ++j)
            iterate(model->index(i, j, index), model, fun);
}

void GUI::Model::ItemUtils::iterate_if(const QModelIndex& index, const QAbstractItemModel* model,
                                       const std::function<bool(const QModelIndex&)>& fun)
{
    bool proceed_with_children(true);
    if (index.isValid())
        proceed_with_children = fun(index);

    if (!model->hasChildren(index) || !proceed_with_children)
        return;

    for (int i = 0; i < model->rowCount(index); ++i)
        for (int j = 0; j < model->columnCount(index); ++j)
            iterate_if(model->index(i, j, index), model, fun);
}

QString GUI::Model::ItemUtils::suggestName(const QStringList& existingNames, const QString& name)
{
    int newNumber = -1;
    QRegExp regexp("\\((\\d+)\\)");

    QString baseName = name;
    if (regexp.indexIn(baseName) >= 0) {
        newNumber = regexp.cap(1).toInt();
        baseName.replace(regexp.cap(0), "");
        baseName = baseName.trimmed();
    }

    for (auto name : existingNames) {
        if (name == baseName)
            newNumber = std::max(newNumber, 2);
        else if (regexp.indexIn(name) >= 0)
            newNumber = std::max(newNumber, regexp.cap(1).toInt() + 1);
    }

    if (newNumber == -1)
        return baseName;

    return QString("%1 (%2)").arg(baseName).arg(newNumber);
}
