//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Models/Sample/SampleModel.h
//! @brief     Defines class SampleModel
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODELS_SAMPLE_SAMPLEMODEL_H
#define BORNAGAIN_GUI_MODELS_SAMPLE_SAMPLEMODEL_H

#include "GUI/Items/SessionModel.h"

class MultiLayerItem;
class ItemWithMaterial;

//! Main model to hold sample items.

class SampleModel : public SessionModel {
    Q_OBJECT

public:
    explicit SampleModel(QObject* parent = nullptr);

    SampleModel* createCopy(SessionItem* parent = nullptr) override;

    virtual QVariant data(const QModelIndex& index, int role) const override;

    MultiLayerItem* multiLayerItem();
    QVector<MultiLayerItem*> multiLayerItems() const;

    //! Returns vector of SessionItems having MaterialProperty on board.
    QVector<ItemWithMaterial*> itemsWithMaterial() const;

    void removeMultiLayer(MultiLayerItem* item);

signals:
    //! This signal is emitted if any data changed (compare to dataChanged), but only if the
    //! change is not about position changes (i.e. moving an item in the sample editor).
    //! item is the one given in the first index of dataChanged(idx1,idx2)
    void nonPositionRelatedDataChanged(const SessionItem* item);

private:
    void onDataChanged(const QModelIndex& index, const QModelIndex&);
};

#endif // BORNAGAIN_GUI_MODELS_SAMPLE_SAMPLEMODEL_H
