//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Models/Types/DoubleDescriptor.cpp
//! @brief     Implements class DoubleDescriptor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Models/Types/DoubleDescriptor.h"
#include "GUI/Items/ModelPath.h"
#include "GUI/Items/SessionItem.h"

DoubleDescriptor::DoubleDescriptor(const QString& label, SessionItem* item,
                                   const variant<QString, Unit>& unit)
    : DoubleDescriptor(
        label, item->toolTip(), item->decimals(), item->limits(),
        [=](double d) { item->setValue(d); }, [=]() { return item->value().toDouble(); }, unit)
{
    path = [=] { return GUI::Model::Path::getPathFromItem(item); };
}

DoubleDescriptor::DoubleDescriptor(SessionItem* item, const variant<QString, Unit>& unit)
    : DoubleDescriptor(item->displayName(), item, unit)
{
}

DoubleDescriptor::DoubleDescriptor(const QString& label, const QString& tooltip,
                                   function<void(double)> setter, function<double()> getter,
                                   const variant<QString, Unit>& unit)
    : DoubleDescriptor(label, tooltip, 3, RealLimits::nonnegative(), setter, getter, unit)
{
}

DoubleDescriptor::DoubleDescriptor(const QString& label, const QString& tooltip, int decimals,
                                   const RealLimits& limits, function<void(double)> setter,
                                   function<double()> getter, const variant<QString, Unit>& unit)
    : label(label)
    , tooltip(tooltip)
    , decimals(decimals)
    , limits(limits)
    , set(setter)
    , get(getter)
    , unit(unit)
{
    // #baLayerEditor the following path creation has to be implemented when SessionItem migration
    // has finished
    path = [] { return QString(); };
}

DoubleDescriptor::DoubleDescriptor(const QString& label, const QString& tooltip, double* var,
                                   const variant<QString, Unit>& unit)
    : DoubleDescriptor(label, tooltip, 3, RealLimits::nonnegative(), var, unit)

{
}

DoubleDescriptor::DoubleDescriptor(const QString& label, const QString& tooltip, int decimals,
                                   const RealLimits& limits, double* var,
                                   const variant<QString, Unit>& unit)
    : DoubleDescriptor(
        label, tooltip, decimals, limits, [=](double v) { *var = v; }, [=] { return *var; }, unit)
{
}

DoubleDescriptor::operator double() const
{
    return get();
}
