//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Models/Types/VectorDescriptor.h
//! @brief     Defines class VectorDescriptor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODELS_TYPES_VECTORDESCRIPTOR_H
#define BORNAGAIN_GUI_MODELS_TYPES_VECTORDESCRIPTOR_H

#include "GUI/Items/VectorItem.h"
#include "GUI/Models/Types/DoubleDescriptor.h"

//! Describes properties of a 3D vector, consisting of three double values.
//!
//! By using this class, the underlying data scheme is hidden from the user of the data. This e.g.
//! eases SessionItem migration. The underlying implementation can be a VectorItem, a member array
//! of three doubles, three double members, or any other construction to hold the three values.
class VectorDescriptor {
public:
    //! Operates on a VectorItem.
    //!
    //! The settings (like decimals, limits) are taken from the item.
    //! Only for easier migration. Should be removed after SessionItem refactoring.
    VectorDescriptor(VectorItem* item, const variant<QString, Unit>& unit)
        : label(item->displayName())
        , tooltip(item->toolTip())
        , x(item->xItem(), unit)
        , y(item->yItem(), unit)
        , z(item->zItem(), unit)
    {
    }

    QString label;   //!< A label text (short, no trailing colon)
    QString tooltip; //!< Tooltip text
    DoubleDescriptor x;
    DoubleDescriptor y;
    DoubleDescriptor z;
};

#endif // BORNAGAIN_GUI_MODELS_TYPES_VECTORDESCRIPTOR_H
