//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/InstrumentWidgets/InclinationAnglesEditor.h
//! @brief     Defines class InclinationAnglesEditor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_INCLINATIONANGLESEDITOR_H
#define BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_INCLINATIONANGLESEDITOR_H

#include <QWidget>

class DistributionSelector;
class QComboBox;
class SpecularBeamInclinationItem;
class SphericalAxisForm;

//! Editor for the case where there is no single inclination angle

class InclinationAnglesEditor : public QWidget {

public:
    explicit InclinationAnglesEditor(QWidget* parent = nullptr,
                                     Qt::WindowFlags f = Qt::WindowFlags());
    void setItem(SpecularBeamInclinationItem* item);
    void clearItem();

private slots:
    void onAxisTypeSelected(int value);
    void showDialog();

private:
    DistributionSelector* m_distributionEditor;
    QComboBox* m_typeComboBox;
    SphericalAxisForm* m_form;
    SpecularBeamInclinationItem* m_item;

    static const QString m_title;
};


#endif // BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_INCLINATIONANGLESEDITOR_H
