//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/JobWidgets/JobListModel.h
//! @brief     Defines class JobListModel
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEWS_JOBWIDGETS_JOBLISTMODEL_H
#define BORNAGAIN_GUI_VIEWS_JOBWIDGETS_JOBLISTMODEL_H

#include <QAbstractListModel>

class JobItem;
class JobModel;

class JobListModel : public QAbstractListModel {
    Q_OBJECT

public:
    JobListModel(JobModel* jobs, QObject* parent = nullptr);
    ~JobListModel();

    virtual int rowCount(const QModelIndex& parent = QModelIndex()) const override;

    virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;

    JobItem* jobForIndex(const QModelIndex& index) const;
    QModelIndex indexForJob(JobItem* job);

    void runJob(const QModelIndex& index);
    void removeJob(const QModelIndex& index);
    void cancelJob(const QModelIndex& index);

private slots:
    void onRowsAboutToBeInserted(const QModelIndex& parent, int start, int end);
    void onRowsInserted(const QModelIndex& parent, int start, int end);

private:
    void attachToJob(JobItem* item);
    void detachFromJob(JobItem* item);
    void notifyJobPropertyChange(JobItem* job, const QString& property);

private:
    JobModel* m_jobs;
};

#endif // BORNAGAIN_GUI_VIEWS_JOBWIDGETS_JOBLISTMODEL_H
