//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/SampleDesigner/DesignerMimeData.cpp
//! @brief     Implements class DesignerMimeData
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Views/SampleDesigner/DesignerMimeData.h"
#include "GUI/CommonWidgets/DesignerHelper.h"
#include <QDrag>
#include <QPixmap>
#include <QWidget>

DesignerMimeData::DesignerMimeData(const QString& className, QDrag* drag) : m_className(className)
{
    drag->setMimeData(this);

    QByteArray itemData;
    QDataStream dataStream(&itemData, QIODevice::WriteOnly);
    dataStream << m_className;
    setData("bornagain/widget", itemData);

    drag->setPixmap(getPixmap(m_className));
    drag->setHotSpot(QPoint(drag->pixmap().width() / 2, drag->pixmap().height() / 2));
}

// Execute a drag and drop operation.
Qt::DropAction DesignerMimeData::execDrag(const QString& className, QWidget* dragSource)
{
    if (className.isEmpty())
        return Qt::IgnoreAction;

    QDrag* drag = new QDrag(dragSource);
    DesignerMimeData* mimeData = new DesignerMimeData(className, drag);
    Q_UNUSED(mimeData);

    const Qt::DropAction executedAction = drag->exec(Qt::CopyAction);

    return executedAction;
}

QString DesignerMimeData::getClassName() const
{
    return m_className;
}

QPixmap DesignerMimeData::getPixmap(const QString& name)
{
    return DesignerHelper::getMimePixmap(name);
}
