//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/SampleDesigner/IView.h
//! @brief     Defines interface IView
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEWS_SAMPLEDESIGNER_IVIEW_H
#define BORNAGAIN_GUI_VIEWS_SAMPLEDESIGNER_IVIEW_H

#include "GUI/Views/SampleDesigner/ViewTypes.h"
#include <QGraphicsObject>
#include <memory>

class SessionGraphicsItem;

//! parent class for graphic representation of all ISampleNode's
class IView : public QGraphicsObject {
    Q_OBJECT
public:
    IView(QGraphicsItem* parent = nullptr);
    virtual ~IView();

    virtual int type() const override;

    virtual void setParameterizedItem(SessionGraphicsItem* item);

    virtual SessionGraphicsItem* getItem();

    virtual void addView(IView* childView, int row = 0);

    //! Call this in case you call deleteLater() for the view and the
    //! linked item itself may not exist any more at the time of deletion
    void unlinkFromItem();

signals:
    void aboutToBeDeleted();

public slots:
    virtual void onChangedX();
    virtual void onChangedY();

protected:
    virtual void update_appearance();
    virtual void onPropertyChange(const QString& propertyName);
    virtual void onSiblingsChange();

    SessionGraphicsItem* m_item;
};

inline int IView::type() const
{
    return GUI::View::Types::IVIEW;
}

inline SessionGraphicsItem* IView::getItem()
{
    return m_item;
}

#endif // BORNAGAIN_GUI_VIEWS_SAMPLEDESIGNER_IVIEW_H
