//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/SampleDesigner/ParticleCompositionForm.h
//! @brief     Defines class ParticleCompositionForm
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEWS_SAMPLEDESIGNER_PARTICLECOMPOSITIONFORM_H
#define BORNAGAIN_GUI_VIEWS_SAMPLEDESIGNER_PARTICLECOMPOSITIONFORM_H

#include <QGroupBox>
#include <QList>

class QAction;
class SampleEditorController;
class ParticleCompositionItem;
class QFormLayout;
class SessionItem;
class ItemWithParticles;

//! Form for editing a particle composition
class ParticleCompositionForm : public QGroupBox {
    Q_OBJECT
public:
    ParticleCompositionForm(QWidget* parent, ParticleCompositionItem* compositionItem,
                            SampleEditorController* ec, bool allowRemove = true);

    void enableStructureEditing(bool b);
    ParticleCompositionItem* compositionItem() const;
    void onParticleAdded(SessionItem* item);
    void onAboutToRemoveParticle(ItemWithParticles* item);

private:
    QFormLayout* m_layout;
    ParticleCompositionItem* m_compositionItem;
    QAction* m_removeAction = nullptr;
    SampleEditorController* m_ec;
    QList<QWidget*> m_structureEditingWidgets;
};

#endif // BORNAGAIN_GUI_VIEWS_SAMPLEDESIGNER_PARTICLECOMPOSITIONFORM_H
