//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/SampleDesigner/ParticleCompositionView.cpp
//! @brief     Implements class ParticleCompositionView
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Views/SampleDesigner/ParticleCompositionView.h"
#include "GUI/CommonWidgets/DesignerHelper.h"
#include "GUI/CommonWidgets/StyleUtils.h"
#include "GUI/Items/ParticleItem.h"

ParticleCompositionView::ParticleCompositionView(QGraphicsItem* parent) : ConnectableView(parent)
{
    setColor(DesignerHelper::getDefaultParticleColor());
    setRectangle(DesignerHelper::getDefaultBoundingRect("ParticleCoreShell"));
    addPort("out", NodeEditorPort::OUTPUT, NodeEditorPort::FORM_FACTOR)
        ->setToolTip("Connect to the ParticleLayout");
    addPort("particles", NodeEditorPort::INPUT, NodeEditorPort::FORM_FACTOR)
        ->setToolTip("Connect particles");
    addPort("transformation", NodeEditorPort::INPUT, NodeEditorPort::TRANSFORMATION)
        ->setToolTip("Connect rotation to this port, if necessary");
    m_label_vspace = GUI::Utils::Style::SizeOfLetterM().height() * 3.0;
}

void ParticleCompositionView::addView(IView* childView, int /* row */)
{
    int index = 0;
    if (ItemWithParticles::isTransformationTagName(getItem()->tagFromItem(childView->getItem())))
        index = 1;
    connectInputPort(dynamic_cast<ConnectableView*>(childView), index);
}
