//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/SampleDesigner/ParticleCoreShellForm.h
//! @brief     Defines class ParticleCoreShellForm
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEWS_SAMPLEDESIGNER_PARTICLECORESHELLFORM_H
#define BORNAGAIN_GUI_VIEWS_SAMPLEDESIGNER_PARTICLECORESHELLFORM_H

#include <QGroupBox>
#include <memory>

class FormLayouter;
class GroupBoxCollapser;
class ParticleCoreShellItem;
class QComboBox;
class SampleEditorController;

//! Form for editing a core/shell particle
class ParticleCoreShellForm : public QGroupBox {
    Q_OBJECT
public:
    ParticleCoreShellForm(QWidget* parent, ParticleCoreShellItem* item, SampleEditorController* ec,
                          bool allowRemove = true);

    void enableStructureEditing(bool b);
    ParticleCoreShellItem* coreShellItem() const;

    void createCoreWidgets();
    void createShellWidgets();

private:
    void onCoreComboChanged();
    void onShellComboChanged();

private:
    ParticleCoreShellItem* m_item;
    QAction* m_removeAction = nullptr;
    SampleEditorController* m_ec;
    struct Location {
        std::unique_ptr<FormLayouter> layouter;
        QComboBox* formFactorCombo = nullptr;
        GroupBoxCollapser* collapser = nullptr;
    };
    Location core;
    Location shell;
};


#endif // BORNAGAIN_GUI_VIEWS_SAMPLEDESIGNER_PARTICLECORESHELLFORM_H
