//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/SampleDesigner/ParticleCoreShellView.cpp
//! @brief     Implements class ParticleCoreShellView
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Views/SampleDesigner/ParticleCoreShellView.h"
#include "GUI/CommonWidgets/DesignerHelper.h"
#include "GUI/CommonWidgets/StyleUtils.h"
#include "GUI/Items/ParticleCoreShellItem.h"

ParticleCoreShellView::ParticleCoreShellView(QGraphicsItem* parent) : ConnectableView(parent)
{
    setColor(DesignerHelper::getDefaultParticleColor());
    setRectangle(DesignerHelper::getDefaultBoundingRect("ParticleCoreShell"));
    addPort("out", NodeEditorPort::OUTPUT, NodeEditorPort::FORM_FACTOR)
        ->setToolTip("Connect to the ParticleLayout");
    addPort("core", NodeEditorPort::INPUT, NodeEditorPort::FORM_FACTOR)
        ->setToolTip("Connect particle which will play the role of core.");
    addPort("shell", NodeEditorPort::INPUT, NodeEditorPort::FORM_FACTOR)
        ->setToolTip("Connect particle which will play the role of shell.");
    addPort("transformation", NodeEditorPort::INPUT, NodeEditorPort::TRANSFORMATION)
        ->setToolTip("Connect particle rotation to this port, if necessary");

    m_label_vspace = GUI::Utils::Style::SizeOfLetterM().height() * 3.0;
}

void ParticleCoreShellView::addView(IView* childView, int /* row */)
{
    int index = 0;
    QString tag = getItem()->tagFromItem(childView->getItem());
    if (ParticleCoreShellItem::isCoreTagName(tag)) {
        index = 0;
    } else if (ParticleCoreShellItem::isShellTagName(tag)) {
        index = 1;
    } else {
        index = 2;
    }
    connectInputPort(dynamic_cast<ConnectableView*>(childView), index);
}
