//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/SampleDesigner/SampleToolBoxTreeWidget.h
//! @brief     Defines class SampleToolBoxTreeWidget
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEWS_SAMPLEDESIGNER_SAMPLETOOLBOXTREEWIDGET_H
#define BORNAGAIN_GUI_VIEWS_SAMPLEDESIGNER_SAMPLETOOLBOXTREEWIDGET_H

#include <QTreeWidget>

class SampleToolBoxGroupView;

//! A tree of groups inside the Sample Designer's Sample toolbox.
//! The toolbox is the selection are at the left side of the Sample Designer.
class SampleToolBoxTreeWidget : public QTreeWidget {
    Q_OBJECT

public:
    explicit SampleToolBoxTreeWidget(QWidget* parent = 0);

    //! Adds a group at the end of the list
    void addGroup(const QString& title);

    //! Adds an entry in the last group
    void addEntry(const QString& modelType, const QIcon& icon, const QString& title,
                  const QString& tooltip);

    void filter(const QString&);

signals:
    void pressed(const QString name, const QString dom_xml, const QPoint& global_mouse_pos);

protected:
    virtual void contextMenuEvent(QContextMenuEvent* e) override;
    virtual void resizeEvent(QResizeEvent* e) override;

private:
    void handleMousePress(QTreeWidgetItem* item);
    void slotListMode();
    void slotIconMode();

    void addGroupView(QTreeWidgetItem* parent, bool iconMode);
    SampleToolBoxGroupView* groupViewAt(int idx) const;
    void adjustSubListSize(QTreeWidgetItem* cat_item);
    void updateViewMode();

private:
    bool m_iconMode;
};

#endif // BORNAGAIN_GUI_VIEWS_SAMPLEDESIGNER_SAMPLETOOLBOXTREEWIDGET_H
