//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/Toplevel/WelcomeView.cpp
//! @brief     Implements class WelcomeView
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Views/Toplevel/WelcomeView.h"
#include "GUI/Project/projectmanager.h"
#include "GUI/Views/SampleDesigner/GroupBoxCollapser.h"
#include "GUI/utils/LayoutUtils.h"
#include "GUI/utils/qstringutils.h"
#include "ui_WelcomeView.h"

#include <QCommandLinkButton>
#include <QDesktopServices>
#include <QDir>
#include <QUrl>

using namespace GUI::Utils;

WelcomeView::WelcomeView(QWidget* parent) : QWidget(parent), m_ui(new Ui::WelcomeView)
{
    m_ui->setupUi(this);

    setAttribute(Qt::WA_StyledBackground, true);
    setProperty("stylable", true); // for stylesheet addressing

    GroupBoxCollapser::installIntoGroupBox(m_ui->groupBox_2);

    QPalette palette = this->palette();
    palette.setColor(QPalette::Window, Qt::white);
    setPalette(palette);

    connect(m_ui->newButton, &QPushButton::clicked, projectManager(), &ProjectManager::newProject);
    connect(m_ui->openButton, &QPushButton::clicked, [=]() { projectManager()->openProject(); });
    connect(m_ui->websiteButton, &QPushButton::clicked,
            []() { QDesktopServices::openUrl(QUrl("https://www.bornagainproject.org")); });
    connect(projectManager(), &ProjectManager::recentListModified, this,
            &WelcomeView::updateRecentProjectPanel);

    updateRecentProjectPanel();
}

ProjectManager* WelcomeView::projectManager()
{
    return ProjectManager::instance();
}

void WelcomeView::updateRecentProjectPanel()
{
    Layout::clearLayout(m_ui->recentProjectsLayout);

    for (const auto& file : projectManager()->recentProjects()) {
        auto button = new QCommandLinkButton;
        button->setText(QFileInfo(file).baseName());
        button->setDescription(String::withTildeHomePath(QDir::toNativeSeparators(file)));
        button->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);
        connect(button, &QCommandLinkButton::clicked, [=] { projectManager()->openProject(file); });

        m_ui->recentProjectsLayout->addWidget(button);
    }
    m_ui->recentProjectsLayout->addStretch(1);
}
