//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/Processed/ProcessedLayout.h
//! @brief     Defines class ProcessedLayout.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_RESAMPLE_PROCESSED_PROCESSEDLAYOUT_H
#define BORNAGAIN_RESAMPLE_PROCESSED_PROCESSEDLAYOUT_H

#include <map>
#include <memory>
#include <vector>

class CoherentFFSum;
class IInterference;
class IParticle;
class ParticleLayout;
class SliceStack;
class Admixtures;

//! Data structure that contains preprocessed data for a single layout.
//!
//! If particles in the layout crossed the limits of the layer slices,
//! these particles will be sliced themselves.

class ProcessedLayout {
public:
    ProcessedLayout(const ParticleLayout& layout, const SliceStack& slices, double z_ref,
                    bool polarized);
    ProcessedLayout(ProcessedLayout&& other);
    ~ProcessedLayout();

    size_t numberOfSlices() const;
    double surfaceDensity() const;
    const std::vector<std::unique_ptr<const CoherentFFSum>>& formFactorList() const;
    const IInterference* interferenceFunction() const;
    const std::map<size_t, Admixtures>& regionMap() const;

private:
    std::unique_ptr<const CoherentFFSum> processParticle(const IParticle& particle,
                                                         const SliceStack& slices, double z_ref,
                                                         double intensity_factor,
                                                         double total_abundance);

    const bool m_polarized;
    const size_t m_n_slices;
    const double m_surface_density;
    std::vector<std::unique_ptr<const CoherentFFSum>> m_formfactors;
    std::unique_ptr<const IInterference> m_iff;
    std::map<size_t, Admixtures> m_slice2admixture;
};

#endif // BORNAGAIN_RESAMPLE_PROCESSED_PROCESSEDLAYOUT_H
#endif // USER_API
