//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/Aggregate/InterferenceFinite3DLattice.h
//! @brief     Defines class InterferenceFinite3DLattice.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_AGGREGATE_INTERFERENCEFINITE3DLATTICE_H
#define BORNAGAIN_SAMPLE_AGGREGATE_INTERFERENCEFINITE3DLATTICE_H

#include "Sample/Aggregate/IInterference.h"
#include "Sample/Lattice/Lattice3D.h"

//! Interference function of a finite 3D lattice.
//! @ingroup interference

class InterferenceFinite3DLattice : public IInterference {
public:
    inline static const std::string class_name = "InterferenceFinite3DLattice";
    std::string className() const final { return class_name; }

    InterferenceFinite3DLattice(const Lattice3D& lattice, unsigned N_1, unsigned N_2, unsigned N_3);
    ~InterferenceFinite3DLattice() override;

    InterferenceFinite3DLattice* clone() const override;

    void accept(INodeVisitor* visitor) const override { visitor->visit(this); }

    unsigned numberUnitCells1() const { return m_N_1; }
    unsigned numberUnitCells2() const { return m_N_2; }
    unsigned numberUnitCells3() const { return m_N_3; }

    const Lattice3D& lattice() const;

    bool supportsMultilayer() const override { return false; }

    std::vector<const INode*> getChildren() const override;

private:
    double iff_without_dw(const R3 q) const override;
    void setLattice(const Lattice3D& lattice);

    std::unique_ptr<Lattice3D> m_lattice;
    unsigned m_N_1, m_N_2, m_N_3; //!< Size of the finite lattice in lattice units
};

#endif // BORNAGAIN_SAMPLE_AGGREGATE_INTERFERENCEFINITE3DLATTICE_H
