//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/Aggregate/InterferenceTwin.h
//! @brief     Defines class InterferenceTwin.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_AGGREGATE_INTERFERENCETWIN_H
#define BORNAGAIN_SAMPLE_AGGREGATE_INTERFERENCETWIN_H

#include "Sample/Aggregate/IInterference.h"

//! Interference function for two particles at a mean distance and given standard deviation
//! from each other in a given direction.
//! @ingroup interference

class InterferenceTwin : public IInterference {
public:
    inline static const std::string class_name = "InterferenceTwin";
    std::string className() const final { return class_name; }

    InterferenceTwin(const R3& direction, double mean_distance, double std_dev);

    InterferenceTwin* clone() const override;

    void accept(INodeVisitor* visitor) const override { visitor->visit(this); }

    R3 direction() const;
    double meanDistance() const;
    double stdDev() const;

private:
    double iff_without_dw(const R3 q) const override;

    R3 m_direction;
    double m_distance;
    double m_std_dev;
};

#endif // BORNAGAIN_SAMPLE_AGGREGATE_INTERFERENCETWIN_H
