//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Tests/Functional/ProStd/MakeSimulations.h
//! @brief     Declares simulation builders for standard tests.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_TESTS_FUNCTIONAL_PROSTD_MAKESIMULATIONS_H
#define BORNAGAIN_TESTS_FUNCTIONAL_PROSTD_MAKESIMULATIONS_H

#include <memory>
#include <string>

class DepthProbeSimulation;
class GISASSimulation;
class SpecularSimulation;
class OffSpecularSimulation;
class MultiLayer;

//! Simulations for standard tests.

namespace test::makeSimulation {

std::unique_ptr<GISASSimulation> MiniGISAS(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> MiniGISAS_v2(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> MiniZPolarizedGISAS(const MultiLayer& sample,
                                                     const std::string& polCase);
std::unique_ptr<GISASSimulation> BasicGISAS(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> SpinflipGISAS(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> MiniGISASBeamDivergence(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> MiniGISASDetectorResolution(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> MiniGISASSpecularPeak(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> GISASWithMasks(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> MaxiGISAS(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> MaxiGISAS00(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> RectDetectorGeneric(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> RectDetectorPerpToSample(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> RectDetectorPerpToDirectBeam(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> RectDetectorPerpToReflectedBeam(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> RectDetectorPerpToReflectedBeamDpos(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> MiniGISASMonteCarlo(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> SphericalDetWithRoi(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> RectDetWithRoi(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> MiniGISASFit(const MultiLayer& sample);
std::unique_ptr<GISASSimulation> ExtraLongWavelengthGISAS(const MultiLayer& sample);

std::unique_ptr<OffSpecularSimulation> MiniOffSpecular(const MultiLayer& sample);

std::unique_ptr<SpecularSimulation> BasicSpecular(const MultiLayer& sample, bool vsQ);
std::unique_ptr<SpecularSimulation> BasicYPolarizedSpecular(const MultiLayer& sample,
                                                            const std::string& polCase, bool vsQ);
std::unique_ptr<SpecularSimulation> SpecularWithGaussianBeam(const MultiLayer& sample);
std::unique_ptr<SpecularSimulation> SpecularWithSquareBeam(const MultiLayer& sample);
std::unique_ptr<SpecularSimulation> SpecularDivergentBeam(const MultiLayer& sample);
std::unique_ptr<SpecularSimulation> TOFRWithRelativeResolution(const MultiLayer& sample);
std::unique_ptr<SpecularSimulation> TOFRWithPointwiseResolution(const MultiLayer& sample);

std::unique_ptr<DepthProbeSimulation> BasicDepthProbe(const MultiLayer& sample);

} // namespace test::makeSimulation

#endif // BORNAGAIN_TESTS_FUNCTIONAL_PROSTD_MAKESIMULATIONS_H
#endif // USER_API
